@@ -134,6 +134,7 @@ import random
 import socket
 import string
 import threading
+from logging import NullHandler
 
 from botocore.compat import six  # noqa: F401
 from botocore.exceptions import IncompleteReadError, ResponseStreamingError
@@ -145,12 +146,7 @@ import s3transfer.compat
 from s3transfer.exceptions import RetriesExceededError, S3UploadFailedError
 
 __author__ = 'Amazon Web Services'
-__version__ = '0.11.4'
-
-
-class NullHandler(logging.Handler):
-    def emit(self, record):
-        pass
+__version__ = '0.14.0'
 
 
 logger = logging.getLogger(__name__)
@@ -513,7 +509,7 @@ class ShutdownQueue(queue.Queue):
         with self._shutdown_lock:
             if self._shutdown:
                 raise QueueShutdownError(
-                    "Cannot put item to queue when " "queue has been shutdown."
+                    "Cannot put item to queue when queue has been shutdown."
                 )
         return queue.Queue.put(self, item)
 
@@ -800,8 +796,7 @@ class S3Transfer:
             )
         except Exception:
             logger.debug(
-                "Exception caught in download_file, removing partial "
-                "file: %s",
+                "Exception caught in download_file, removing partial file: %s",
                 temp_filename,
                 exc_info=True,
             )
